@@ -15,23 +15,23 @@ from panel import __version__
 from panel.io.convert import convert_app
 
 from panel_sharing import VERSION, config
-from panel_sharing.utils import set_directory
+from panel_sharing.utils import Timer, set_directory
 
 ctx_forkserver = multiprocessing.get_context("forkserver")
 ctx_forkserver.set_forkserver_preload(
     [
-        "base64",
+        # "base64",
         "bokeh",
         "holoviews",
         "hvplot",
-        "io",
-        "matplotlib",
+        # "io",
+        # "matplotlib",
         "numpy",
         "pandas",
         "panel",
         "param",
-        "PIL",
-        "skimage",
+        # "PIL",
+        # "skimage",
     ]
 )
 
@@ -79,6 +79,15 @@ class Source(param.Parameterized):
         source.requirements = (path / "requirements.txt").read_text()
         return source
 
+    def to_dict(self) -> Dict:
+        """Returns the source as a dict"""
+        return {
+            "code": self.code,
+            "readme": self.readme,
+            "thumbnail": self.thumbnail,
+            "requirements": self.requirements,
+        }
+
 
 class Project(param.Parameterized):
     """A project consists of configuration and source files"""
@@ -152,14 +161,15 @@ class Project(param.Parameterized):
 
         # We need to be really careful when we convert. See
         # https://github.com/holoviz/panel/issues/3939
-        process = ctx_forkserver.Process(
-            target=_convert_project,
-            kwargs=kwargs,
-        )
-        process.start()
+        with Timer("convert project"):
+            process = ctx_forkserver.Process(
+                target=_convert_project,
+                kwargs=kwargs,
+            )
+            process.start()
 
-        self.save_build_json(kwargs)
-        process.join()
+            self.save_build_json(kwargs)
+            process.join()
         if base_target != "":
             app_html = pathlib.Path("build/app.html")
             text = app_html.read_text(encoding="utf8")
@@ -170,7 +180,7 @@ class Project(param.Parameterized):
 class User(param.Parameterized):
     """A User of the site"""
 
-    name = param.String(config.USER_NAME, constant=True, regex=config.USER_NAME_REGEX)
+    name = param.String(config.GUEST_USER_NAME, constant=True, regex=config.USER_NAME_REGEX)
     authenticated = param.Boolean(config.AUTHENTICATED, constant=True)
 
     def __init__(self, **params):
@@ -178,11 +188,21 @@ class User(param.Parameterized):
 
         if "name" not in params:
             with param.edit_constant(self):
-                self.name = config.USER_NAME
+                self.name = config.GUEST_USER_NAME
 
     def __str__(self):
         return self.name
 
+    def authenticate(self, name):
+        """Authenticates the give name"""
+        with param.edit_constant(self):
+            if name and name != config.GUEST_USER_NAME:
+                self.name = name
+                self.authenticated = True
+            else:
+                self.name = config.GUEST_USER_NAME
+                self.authenticated = False
+
 
 class Storage(param.Parameterized):
     """Represent a key-value where the value is a Project"""
